@@ -65,14 +65,14 @@ class UdpSession(object):
     def send_packet(cls, packet_type, ctx, datas=[]):
         import whatap.net.udp_thread
         try:
-            if len(b''.join(cls.buffer_arr)) > PacketEnum.PACKET_BUFFER_SIZE:
+            if sum( [ len(x) for x in cls.buffer_arr]) + sum( [len(x) if isinstance(x, (str, bytes)) else 4 for x in datas ] ) +PacketEnum.PACKET_BODY_REQUIRED_SIZE + 1 > PacketEnum.PACKET_BUFFER_SIZE:
                 cls.send(packet_type, ctx)
 
             if not datas:
                 return
 
             dout = DataOutputX()
-            start_header_buffer_size = len(dout.buffer.getvalue())
+            start_header_buffer_size = dout.size()
 
             # header
             dout.writeByte(packet_type)
@@ -80,7 +80,7 @@ class UdpSession(object):
             dout.writeInt(0)
 
             # body
-            start_body_buffer_size = len(dout.buffer.getvalue())
+            start_body_buffer_size = dout.size()
 
             if ctx:
                 dout.writeLong(ctx.id)
@@ -92,9 +92,9 @@ class UdpSession(object):
                 dout.writeLong(ctx.thread_id)
 
             diff = PacketEnum.PACKET_BUFFER_SIZE \
-                   - len(b''.join(cls.buffer_arr)) - (PacketEnum.PACKET_BODY_REQUIRED_SIZE + 1)
+                   - sum( [len(x) for x  in cls.buffer_arr]) - (PacketEnum.PACKET_BODY_REQUIRED_SIZE + 1)
             for data in datas:
-                data = str(data)
+                data = str(data)[:PacketEnum.DATA_SIZE_LIMIT]
                 diff -= len(data)
                 if diff < 0:
                     data = ' '
@@ -105,7 +105,7 @@ class UdpSession(object):
             with cls.thread_lock:
                 dout.writeToPos(
                     start_header_buffer_size + PacketEnum.PACKET_HEADER_LEN_POS,
-                    len(dout.buffer.getvalue()) - start_body_buffer_size)
+                    dout.size() - start_body_buffer_size)
 
                 cls.buffer_arr.append(dout.buffer.getvalue())
 
@@ -126,6 +126,7 @@ class UdpSession(object):
         #         print('pack_type: ', extra={'id': 'WA919'}, exc_info=True)
 
         try:
+            from datetime import datetime
             s.sendall(b''.join(cls.buffer_arr))
         except ConnectionRefusedError as e:
             logging.debug(e, extra={'id': 'WA911'}, exc_info=True)
