@@ -58,13 +58,16 @@ def trace_handler(fn, start=False):
                 callback = func(*args, **kwargs)
             except Exception as e:
                 if ctx and ctx.error_step ==e:
-                    raise ctx.error_step
+                    ctx.error_step= None
+                    raise e
                 logging.debug(e, extra={'id': 'WA917'}, exc_info=True)
                 print(e, dict(extra={'id': 'WA917'}, exc_info=True))
                 return fn(*args, **kwargs)
             else:
                 if ctx and ctx.error_step:
-                    raise ctx.error_step
+                    e = ctx.error_step
+                    ctx.error_step = None
+                    raise e
                 return callback
         
         return wrapper
@@ -393,10 +396,8 @@ def addQuote(arg_dict):
     return quoted_dict
 
 def interceptor_db_execute(fn, *args, **kwargs):
-    # print('interceptor_db_execute step -1')
     ctx = TraceContextManager.getLocalContext()
     #sendDebugProfile(ctx, 'interceptor_db_execute step -1')
-    # print('interceptor_db_execute step -2 ctx:', ctx)
     self = args[0]
     query = None
     if len(args) > 2 and type(args[2]) == dict and args[2]:
@@ -409,33 +410,25 @@ def interceptor_db_execute(fn, *args, **kwargs):
             query = args[1].decode()
     except Exception as e:
         query = args[1]
-    #print('interceptor_db_execute step -3', query)
     if not query or ctx.active_sqlhash:
-        #print('interceptor_db_execute step -3.1', ctx.active_sqlhash)
         return fn(*args, **kwargs)
 
 
-    # print('interceptor_db_execute step -4')
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
     ctx.active_sqlhash = query
-    # print('interceptor_db_execute step -5')
     try:
         callback = fn(*args, **kwargs)
-        # print('interceptor_db_execute step -6')
         return callback
     except Exception as e:
         interceptor_step_error(e)
     finally:
-        # print('interceptor_db_execute step -7 txid:', ctx.id)
         ctx = TraceContextManager.getLocalContext()
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
                                datas)
-        # print('interceptor_db_execute step -8')
         count = self.rowcount
-        # print('interceptor_db_execute step -9', count)
         if count > -1:
             desc = '{0}: {1}'.format('Fetch count', count)
             datas = [' ', ' ', desc]
@@ -443,8 +436,7 @@ def interceptor_db_execute(fn, *args, **kwargs):
             UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
         
         ctx.active_sqlhash = 0
-        # print('interceptor_db_execute step -10')
-
+        
 def interceptor_db_close(fn, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
     ctx.db_opening = False
